<?php
// $Id: Timelinemap.class.inc,v 1.1 2010/03/04 13:37:14 vesnaradivojevic Exp $

/**
 * @file
 * Class Timelinemap
 */

class Timelinemap {

  var $view;
  var $data;
  var $sets;
  var $dateformat;
  var $color_id = 0;

  /**
   * Constructor.
   *
   * @param $view
   */
  function __construct(&$view, $sets) {
    $this->view = $view;
    $this->sets = $sets;
    $this->dateformat = 'iso8601';

    $this->data['events'] = $this->getEvents();
    $this->data['id'] = $view->name .'-'. $view->current_display;
    $this->data['bands'] = $this->getBands();
    $this->data['summary'] = drupal_strtoupper($view->style_options['bands']['band2_unit']);
    $this->data['timelinemaptype'] = $this->get_type();
    $this->data['pathcolor'] = $this->view->style_options['pathcolor'];
    $this->data['display_name'] = $view->name .'-'. $view->current_display;
  }
  
  /*
  * Send data to json - Drupal.setting.timelinemap
  *
  */
  function timelinemap_to_json() {
    drupal_add_js(array('timelinemap' => array($this->data['id'] => $this->data)), 'setting');
  }
  
  /*
  * Make TimelinemapEvent objects for each $sets
  *
  */
  function getEvents() {
    $events = array();
    if (!empty($this->view->result)) {
      foreach ($this->sets as $k => $set) { 
        $css_selector = $this->generateCssSelector();
        $color = FALSE; 
        if (isset($this->view->style_options['grouping']) && $this->view->style_options['grouping'] != '') {
          $color = $this->getColor(); 
        }

        foreach ($set as $row) {
          $event = new TimelinemapEvent($this->view, $row, $this->dateformat, $css_selector, $color);
          if ($event->getData()) { 
            $events[] = $event->getData();
          }
        }
      }
    }
    return array( 
      'events' => $events,
      'dateTimeFormat' => $this->dateformat,
    );
  }

  function getBands() {
    $bands = array();
    $bands[] = drupal_strtoupper($this->view->style_options['bands']['band1_unit']);
    return $bands;
  }
  
  /*
  * Get timemap display type (basic or pathline)
  *
  */
  function get_type() {
    $type = $this->view->style_options['datasource'];
    return $type;
  } 
  
  function getColor() {
    if (isset($this->view->style_options['colors']['values']) && count($this->view->style_options['colors']['values']) != 0) {
      $colors = array_values($this->view->style_options['colors']['values']);
      $tmp = $this->color_id;
      $this->color_id++;
      while ($tmp >= count($colors)) {
        $tmp = $tmp - count($colors);
      } 
      return $colors[$tmp];
    } 
      else return 'red';
  }

  function generateCssSelector() {
    return $this->view->name . '-set-' . $this->color_id;
  }
}