/*
 *  @file timeline.js
 */	

Drupal.timelinemap = {

  createWidget: function(args) {
	items = [];
	$.each(args.events.events, function(j, u){ 
		if(u.color == 'light blue' || u.color == 'Light blue')
			var color = 'ltblue';
		else var color = u.color;
		
		if(u.link)
		    var htmltitle = "<a href = '" + u.link + "'>" + u.title + "</a>";
		else 
            var htmltitle = u.title; 		
		
		items[j] = {"start" : u.start,
					
					 "point" :  {
							  "lat" : u.latitude,
							  "lon" : u.longitude
						   },
					 "title" : u.title,
					 "options" : {
							// use the default title/description info window
							"infoHtml": htmltitle + '<div class = "description">' + ((u.icon != null) ? '<div class = "image"><img src = "' + u.icon + '" /></div>' : '') + ((u.descriptiontext != null) ? u.descriptiontext : '') + '</div>',
							"theme": color
					 }
					};
		if(u.end)				
			items[j]["end"] = u.end;
	}); 
	var mainBandInt;
	var summBandInt;
	switch (args.bands[0]) {
		case 'SECOND': mainBandInt = Timeline.DateTime.SECOND; break;
		case 'MINUTE': mainBandInt = Timeline.DateTime.MINUTE; break;
		case 'HOUR': mainBandInt = Timeline.DateTime.HOUR; break;
		case 'DAY': mainBandInt = Timeline.DateTime.DAY; break;
		case 'WEEK': mainBandInt = Timeline.DateTime.WEEK; break;
		case 'MONTH': mainBandInt = Timeline.DateTime.MONTH; break;
		case 'YEAR': mainBandInt = Timeline.DateTime.YEAR; break;
		case 'DECADE': mainBandInt = Timeline.DateTime.DECADE; break;
		case 'CENTURY': mainBandInt = Timeline.DateTime.CENTURY; break;
		case 'MILLENNIUM': mainBandInt = Timeline.DateTime.MILLENNIUM; break;
		default: mainBandInt = 'unknown';
	}
	switch (args.summary) {
		case 'SECOND': summBandInt = Timeline.DateTime.SECOND; break;
		case 'MINUTE': summBandInt = Timeline.DateTime.MINUTE; break;
		case 'HOUR': summBandInt = Timeline.DateTime.HOUR; break;
		case 'DAY': summBandInt = Timeline.DateTime.DAY; break;
		case 'WEEK': summBandInt = Timeline.DateTime.WEEK; break;
		case 'MONTH': summBandInt = Timeline.DateTime.MONTH; break;
		case 'YEAR': summBandInt = Timeline.DateTime.YEAR; break;
		case 'DECADE': summBandInt = Timeline.DateTime.DECADE; break;
		case 'CENTURY': summBandInt = Timeline.DateTime.CENTURY; break;
		case 'MILLENNIUM': summBandInt = Timeline.DateTime.MILLENNIUM; break;
		default: summBandInt = Timeline.DateTime.YEAR;;
	}	
    
	//if pathline type: pathcolor
	var pathcolor = args.pathcolor;
	if(args.timelinemaptype == 'basic'){
		tm = TimeMap.init({
			mapId: "map-"+args.display_name,               // Id of map div element (required)
			timelineId: "timeline-"+args.display_name,     // Id of timeline div element (required)
			options: {
				eventIconPath: Drupal.settings.basePath + Drupal.settings.timelinemap_path +'/images/'
			},
			datasets: [
				{
					id: "timelinemap",
					title: "Timelinemap",
					theme: "red",
					type: "basic",
					options: {
						items: items
					}
				}
			],
			bandIntervals: [
				mainBandInt, 
				summBandInt
			]
		});
	} else if(args.timelinemaptype == 'pathline'){
	    tm = TimeMap.init({
			mapId: "map-"+args.display_name,               // Id of map div element (required)
			timelineId: "timeline-"+args.display_name,     // Id of timeline div element (required)
			options: {
				eventIconPath: Drupal.settings.basePath + Drupal.settings.timelinemap_path +'/images/'
			},
			datasets: [
				{
					id: "timelinemap",
					title: "Timelinemap",
					theme: "red",
					type: "basic",
					options: {
						items: items
					}
				}
			],
			bandIntervals: [
				mainBandInt, 
				summBandInt
			],
			dataDisplayedFunction: function(tm) {
				// new filter chain for map lines
				tm.addFilterChain("pathlines",
					// true condition: add a pathline
					function(item) {
						if (!item.pathline && !item.skip) {
							item.pathline = new GPolyline([item.opts.infoPoint, item.next.opts.infoPoint], pathcolor);
							tm.map.addOverlay(item.pathline);
						}
					},
					// false condition: remove a pathline
					function(item) {
						if (item.pathline) {
							tm.map.removeOverlay(item.pathline);
							item.pathline = null;
						}
					}
				);
				// define the filter that creates the pathlines
				tm.addFilter("pathlines", function(item) {
					if (!item.next && item.event && !item.skip) {
						// use the Timeline sequential iterator
						var i = tm.timeline.getBand(0).getEventSource().getEventIterator(item.event.getStart(), new Date());
						FINDNEXT: {
							while (!item.next) {
								if (i.hasNext()) {
									var next = i.next().item;
									// if the next one's taken we can skip
									if (next.taken) {
										item.skip = true;
										break FINDNEXT;
									}
									// skip missing placemarks at the same location
									if (next.placemark && !item.opts.infoPoint.equals(next.opts.infoPoint)) {
										item.next = next;
										next.taken = true;
									}
								}
								else break FINDNEXT;
							}
						}
					}
					return (item.next && item.placemarkVisible && item.next.placemarkVisible);
				});
				// invoke the filter once data is displayed
				tm.filter("pathlines");
				// update map on timeline scroll
				tm.timeline.getBand(0).addOnScrollListener(function() {
					tm.filter("pathlines");
				});
			}
		});
	}
  }
}; 
Drupal.behaviors.timelinemap = function(context) {
  if(Drupal.settings.timelinemap) { 
	 $('.timelinemap-all').each(function() { var d=0;
			$.each(Drupal.settings.timelinemap, function(i, v) {
			  Drupal.timelinemap.createWidget(v); 
			});
			
	 })
  }
}